# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import wds_client
from wds_client.api.instances_api import InstancesApi  # noqa: E501
from wds_client.rest import ApiException


class TestInstancesApi(unittest.TestCase):
    """InstancesApi unit test stubs"""

    def setUp(self):
        self.api = wds_client.api.instances_api.InstancesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_wds_instance(self):
        """Test case for create_wds_instance

        Create an instance  # noqa: E501
        """
        pass

    def test_delete_wds_instance(self):
        """Test case for delete_wds_instance

        Delete an instance  # noqa: E501
        """
        pass

    def test_list_wds_instances(self):
        """Test case for list_wds_instances

        List instances  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wds_client.api_client import ApiClient
from wds_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class SchemaApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_record_type(self, instanceid, v, type, **kwargs):  # noqa: E501
        """Delete record type  # noqa: E501

        Delete record type. All records of this type will be deleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_record_type(instanceid, v, type, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str instanceid: WDS instance id; by convention equal to workspace id (required)
        :param str v: API version (required)
        :param str type: Record type (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_record_type_with_http_info(instanceid, v, type, **kwargs)  # noqa: E501

    def delete_record_type_with_http_info(self, instanceid, v, type, **kwargs):  # noqa: E501
        """Delete record type  # noqa: E501

        Delete record type. All records of this type will be deleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_record_type_with_http_info(instanceid, v, type, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str instanceid: WDS instance id; by convention equal to workspace id (required)
        :param str v: API version (required)
        :param str type: Record type (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'instanceid',
            'v',
            'type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_record_type" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'instanceid' is set
        if self.api_client.client_side_validation and ('instanceid' not in local_var_params or  # noqa: E501
                                                        local_var_params['instanceid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `instanceid` when calling `delete_record_type`")  # noqa: E501
        # verify the required parameter 'v' is set
        if self.api_client.client_side_validation and ('v' not in local_var_params or  # noqa: E501
                                                        local_var_params['v'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `v` when calling `delete_record_type`")  # noqa: E501
        # verify the required parameter 'type' is set
        if self.api_client.client_side_validation and ('type' not in local_var_params or  # noqa: E501
                                                        local_var_params['type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `type` when calling `delete_record_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instanceid' in local_var_params:
            path_params['instanceid'] = local_var_params['instanceid']  # noqa: E501
        if 'v' in local_var_params:
            path_params['v'] = local_var_params['v']  # noqa: E501
        if 'type' in local_var_params:
            path_params['type'] = local_var_params['type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/{instanceid}/types/{v}/{type}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_all_record_types(self, instanceid, v, **kwargs):  # noqa: E501
        """Describe all record types  # noqa: E501

        Returns the schema definition for all types in this instance.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_all_record_types(instanceid, v, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str instanceid: WDS instance id; by convention equal to workspace id (required)
        :param str v: API version (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[RecordTypeSchema]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.describe_all_record_types_with_http_info(instanceid, v, **kwargs)  # noqa: E501

    def describe_all_record_types_with_http_info(self, instanceid, v, **kwargs):  # noqa: E501
        """Describe all record types  # noqa: E501

        Returns the schema definition for all types in this instance.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_all_record_types_with_http_info(instanceid, v, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str instanceid: WDS instance id; by convention equal to workspace id (required)
        :param str v: API version (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[RecordTypeSchema], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'instanceid',
            'v'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_all_record_types" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'instanceid' is set
        if self.api_client.client_side_validation and ('instanceid' not in local_var_params or  # noqa: E501
                                                        local_var_params['instanceid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `instanceid` when calling `describe_all_record_types`")  # noqa: E501
        # verify the required parameter 'v' is set
        if self.api_client.client_side_validation and ('v' not in local_var_params or  # noqa: E501
                                                        local_var_params['v'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `v` when calling `describe_all_record_types`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instanceid' in local_var_params:
            path_params['instanceid'] = local_var_params['instanceid']  # noqa: E501
        if 'v' in local_var_params:
            path_params['v'] = local_var_params['v']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/{instanceid}/types/{v}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RecordTypeSchema]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def describe_record_type(self, instanceid, v, type, **kwargs):  # noqa: E501
        """Describe record type  # noqa: E501

        Returns the schema definition for this type.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_record_type(instanceid, v, type, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str instanceid: WDS instance id; by convention equal to workspace id (required)
        :param str v: API version (required)
        :param str type: Record type (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RecordTypeSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.describe_record_type_with_http_info(instanceid, v, type, **kwargs)  # noqa: E501

    def describe_record_type_with_http_info(self, instanceid, v, type, **kwargs):  # noqa: E501
        """Describe record type  # noqa: E501

        Returns the schema definition for this type.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.describe_record_type_with_http_info(instanceid, v, type, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str instanceid: WDS instance id; by convention equal to workspace id (required)
        :param str v: API version (required)
        :param str type: Record type (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RecordTypeSchema, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'instanceid',
            'v',
            'type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method describe_record_type" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'instanceid' is set
        if self.api_client.client_side_validation and ('instanceid' not in local_var_params or  # noqa: E501
                                                        local_var_params['instanceid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `instanceid` when calling `describe_record_type`")  # noqa: E501
        # verify the required parameter 'v' is set
        if self.api_client.client_side_validation and ('v' not in local_var_params or  # noqa: E501
                                                        local_var_params['v'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `v` when calling `describe_record_type`")  # noqa: E501
        # verify the required parameter 'type' is set
        if self.api_client.client_side_validation and ('type' not in local_var_params or  # noqa: E501
                                                        local_var_params['type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `type` when calling `describe_record_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'instanceid' in local_var_params:
            path_params['instanceid'] = local_var_params['instanceid']  # noqa: E501
        if 'v' in local_var_params:
            path_params['v'] = local_var_params['v']  # noqa: E501
        if 'type' in local_var_params:
            path_params['type'] = local_var_params['type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/{instanceid}/types/{v}/{type}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RecordTypeSchema',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from wds_client.configuration import Configuration


class RequestBodySearch(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'terms': 'str',
        'operator': 'SearchOperator'
    }

    attribute_map = {
        'terms': 'terms',
        'operator': 'operator'
    }

    def __init__(self, terms=None, operator=None, local_vars_configuration=None):  # noqa: E501
        """RequestBodySearch - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._terms = None
        self._operator = None
        self.discriminator = None

        self.terms = terms
        if operator is not None:
            self.operator = operator

    @property
    def terms(self):
        """Gets the terms of this RequestBodySearch.  # noqa: E501

        Space-delimited list of terms on which to search  # noqa: E501

        :return: The terms of this RequestBodySearch.  # noqa: E501
        :rtype: str
        """
        return self._terms

    @terms.setter
    def terms(self, terms):
        """Sets the terms of this RequestBodySearch.

        Space-delimited list of terms on which to search  # noqa: E501

        :param terms: The terms of this RequestBodySearch.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and terms is None:  # noqa: E501
            raise ValueError("Invalid value for `terms`, must not be `None`")  # noqa: E501

        self._terms = terms

    @property
    def operator(self):
        """Gets the operator of this RequestBodySearch.  # noqa: E501


        :return: The operator of this RequestBodySearch.  # noqa: E501
        :rtype: SearchOperator
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this RequestBodySearch.


        :param operator: The operator of this RequestBodySearch.  # noqa: E501
        :type: SearchOperator
        """

        self._operator = operator

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestBodySearch):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RequestBodySearch):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import wds_client
from wds_client.api.general_wds_information_api import GeneralWDSInformationApi  # noqa: E501
from wds_client.rest import ApiException


class TestGeneralWDSInformationApi(unittest.TestCase):
    """GeneralWDSInformationApi unit test stubs"""

    def setUp(self):
        self.api = wds_client.api.general_wds_information_api.GeneralWDSInformationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_status_get(self):
        """Test case for status_get

        Gets health status for WDS -- generated via Spring Boot Actuator (see https://docs.spring.io/spring-boot/docs/current/actuator-api/htmlsingle/#health for details)  # noqa: E501
        """
        pass

    def test_version_get(self):
        """Test case for version_get

        Gets related git and build version info for WDS -- generated via Spring Boot Actuator (see https://docs.spring.io/spring-boot/docs/current/actuator-api/htmlsingle/#info for details)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import wds_client
from wds_client.api.records_api import RecordsApi  # noqa: E501
from wds_client.rest import ApiException


class TestRecordsApi(unittest.TestCase):
    """RecordsApi unit test stubs"""

    def setUp(self):
        self.api = wds_client.api.records_api.RecordsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_batch_write_records(self):
        """Test case for batch_write_records

        Batch write records  # noqa: E501
        """
        pass

    def test_create_or_replace_record(self):
        """Test case for create_or_replace_record

        Create or replace record  # noqa: E501
        """
        pass

    def test_delete_record(self):
        """Test case for delete_record

        Delete record  # noqa: E501
        """
        pass

    def test_get_record(self):
        """Test case for get_record

        Get record  # noqa: E501
        """
        pass

    def test_get_records_as_tsv(self):
        """Test case for get_records_as_tsv

        Retrieve all records in record type as tsv.  # noqa: E501
        """
        pass

    def test_query_records(self):
        """Test case for query_records

        Query records  # noqa: E501
        """
        pass

    def test_update_record(self):
        """Test case for update_record

        Update record  # noqa: E501
        """
        pass

    def test_upload_tsv(self):
        """Test case for upload_tsv

        Import records to a record type from a tsv file  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import wds_client
from wds_client.models.search_request import SearchRequest  # noqa: E501
from wds_client.rest import ApiException

class TestSearchRequest(unittest.TestCase):
    """SearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SearchRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = wds_client.models.search_request.SearchRequest()  # noqa: E501
        if include_optional :
            return SearchRequest(
                offset = 0, 
                limit = 0, 
                sort = 'asc', 
                sort_attribute = '0'
            )
        else :
            return SearchRequest(
        )

    def testSearchRequest(self):
        """Test SearchRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from wds_client.models.attribute_schema import AttributeSchema
from wds_client.models.batch_operation import BatchOperation
from wds_client.models.batch_record_request import BatchRecordRequest
from wds_client.models.batch_response import BatchResponse
from wds_client.models.build import Build
from wds_client.models.commit import Commit
from wds_client.models.component import Component
from wds_client.models.components import Components
from wds_client.models.db_component import DbComponent
from wds_client.models.error_response import ErrorResponse
from wds_client.models.git import Git
from wds_client.models.inline_object import InlineObject
from wds_client.models.record_attribute_definition import RecordAttributeDefinition
from wds_client.models.record_query_response import RecordQueryResponse
from wds_client.models.record_request import RecordRequest
from wds_client.models.record_response import RecordResponse
from wds_client.models.record_type_schema import RecordTypeSchema
from wds_client.models.request_body_search import RequestBodySearch
from wds_client.models.search_operator import SearchOperator
from wds_client.models.search_request import SearchRequest
from wds_client.models.search_sort_direction import SearchSortDirection
from wds_client.models.stack_trace_element import StackTraceElement
from wds_client.models.status_response import StatusResponse
from wds_client.models.tsv_upload_response import TsvUploadResponse
from wds_client.models.version_response import VersionResponse



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from wds_client.configuration import Configuration


class RecordTypeSchema(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'attributes': 'list[AttributeSchema]',
        'count': 'int',
        'primary_key': 'str'
    }

    attribute_map = {
        'name': 'name',
        'attributes': 'attributes',
        'count': 'count',
        'primary_key': 'primaryKey'
    }

    def __init__(self, name=None, attributes=None, count=None, primary_key=None, local_vars_configuration=None):  # noqa: E501
        """RecordTypeSchema - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._attributes = None
        self._count = None
        self._primary_key = None
        self.discriminator = None

        self.name = name
        self.attributes = attributes
        self.count = count
        self.primary_key = primary_key

    @property
    def name(self):
        """Gets the name of this RecordTypeSchema.  # noqa: E501

        Record type name, valid characters for record type names are limited to letters, numbers, spaces, dashes, and underscores.  # noqa: E501

        :return: The name of this RecordTypeSchema.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RecordTypeSchema.

        Record type name, valid characters for record type names are limited to letters, numbers, spaces, dashes, and underscores.  # noqa: E501

        :param name: The name of this RecordTypeSchema.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def attributes(self):
        """Gets the attributes of this RecordTypeSchema.  # noqa: E501


        :return: The attributes of this RecordTypeSchema.  # noqa: E501
        :rtype: list[AttributeSchema]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this RecordTypeSchema.


        :param attributes: The attributes of this RecordTypeSchema.  # noqa: E501
        :type: list[AttributeSchema]
        """
        if self.local_vars_configuration.client_side_validation and attributes is None:  # noqa: E501
            raise ValueError("Invalid value for `attributes`, must not be `None`")  # noqa: E501

        self._attributes = attributes

    @property
    def count(self):
        """Gets the count of this RecordTypeSchema.  # noqa: E501

        Number of records of this type  # noqa: E501

        :return: The count of this RecordTypeSchema.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this RecordTypeSchema.

        Number of records of this type  # noqa: E501

        :param count: The count of this RecordTypeSchema.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and count is None:  # noqa: E501
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    @property
    def primary_key(self):
        """Gets the primary_key of this RecordTypeSchema.  # noqa: E501

        Attribute name that contains the value to uniquely identify each record, defined as a primary key column in the underlying table.  # noqa: E501

        :return: The primary_key of this RecordTypeSchema.  # noqa: E501
        :rtype: str
        """
        return self._primary_key

    @primary_key.setter
    def primary_key(self, primary_key):
        """Sets the primary_key of this RecordTypeSchema.

        Attribute name that contains the value to uniquely identify each record, defined as a primary key column in the underlying table.  # noqa: E501

        :param primary_key: The primary_key of this RecordTypeSchema.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and primary_key is None:  # noqa: E501
            raise ValueError("Invalid value for `primary_key`, must not be `None`")  # noqa: E501

        self._primary_key = primary_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecordTypeSchema):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RecordTypeSchema):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from wds_client.configuration import Configuration


class AttributeSchema(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'datatype': 'str',
        'relates_to': 'str'
    }

    attribute_map = {
        'name': 'name',
        'datatype': 'datatype',
        'relates_to': 'relatesTo'
    }

    def __init__(self, name=None, datatype=None, relates_to=None, local_vars_configuration=None):  # noqa: E501
        """AttributeSchema - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._datatype = None
        self._relates_to = None
        self.discriminator = None

        self.name = name
        self.datatype = datatype
        if relates_to is not None:
            self.relates_to = relates_to

    @property
    def name(self):
        """Gets the name of this AttributeSchema.  # noqa: E501

        name of this attribute.  # noqa: E501

        :return: The name of this AttributeSchema.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AttributeSchema.

        name of this attribute.  # noqa: E501

        :param name: The name of this AttributeSchema.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def datatype(self):
        """Gets the datatype of this AttributeSchema.  # noqa: E501

        Datatype of this attribute. The enum of datatypes is in flux and will change. Please comment at https://docs.google.com/document/d/1d352ZoN5kEYWPjy0NqqWGxdf7HEu5VEdrLmiAv7dMmQ/edit#heading=h.naxag0augkgf.   # noqa: E501

        :return: The datatype of this AttributeSchema.  # noqa: E501
        :rtype: str
        """
        return self._datatype

    @datatype.setter
    def datatype(self, datatype):
        """Sets the datatype of this AttributeSchema.

        Datatype of this attribute. The enum of datatypes is in flux and will change. Please comment at https://docs.google.com/document/d/1d352ZoN5kEYWPjy0NqqWGxdf7HEu5VEdrLmiAv7dMmQ/edit#heading=h.naxag0augkgf.   # noqa: E501

        :param datatype: The datatype of this AttributeSchema.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and datatype is None:  # noqa: E501
            raise ValueError("Invalid value for `datatype`, must not be `None`")  # noqa: E501
        allowed_values = ["BOOLEAN", "NUMBER", "DATE", "DATE_TIME", "STRING", "JSON", "RELATION", "FILE", "ARRAY_OF_BOOLEAN", "ARRAY_OF_STRING", "ARRAY_OF_NUMBER", "ARRAY_OF_DATE", "ARRAY_OF_DATE_TIME", "ARRAY_OF_RELATION", "ARRAY_OF_FILE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and datatype not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `datatype` ({0}), must be one of {1}"  # noqa: E501
                .format(datatype, allowed_values)
            )

        self._datatype = datatype

    @property
    def relates_to(self):
        """Gets the relates_to of this AttributeSchema.  # noqa: E501

        Name of type to which this attribute relates. Only present if this is a relation attribute.  # noqa: E501

        :return: The relates_to of this AttributeSchema.  # noqa: E501
        :rtype: str
        """
        return self._relates_to

    @relates_to.setter
    def relates_to(self, relates_to):
        """Sets the relates_to of this AttributeSchema.

        Name of type to which this attribute relates. Only present if this is a relation attribute.  # noqa: E501

        :param relates_to: The relates_to of this AttributeSchema.  # noqa: E501
        :type: str
        """

        self._relates_to = relates_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttributeSchema):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AttributeSchema):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  As of v0.2, all APIs are subject to change without notice.   # noqa: E501

    The version of the OpenAPI document: v0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from wds_client.configuration import Configuration


class RecordQueryResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'search_request': 'SearchRequest',
        'total_records': 'int',
        'records': 'list[RecordResponse]'
    }

    attribute_map = {
        'search_request': 'searchRequest',
        'total_records': 'totalRecords',
        'records': 'records'
    }

    def __init__(self, search_request=None, total_records=None, records=None, local_vars_configuration=None):  # noqa: E501
        """RecordQueryResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._search_request = None
        self._total_records = None
        self._records = None
        self.discriminator = None

        self.search_request = search_request
        self.total_records = total_records
        self.records = records

    @property
    def search_request(self):
        """Gets the search_request of this RecordQueryResponse.  # noqa: E501


        :return: The search_request of this RecordQueryResponse.  # noqa: E501
        :rtype: SearchRequest
        """
        return self._search_request

    @search_request.setter
    def search_request(self, search_request):
        """Sets the search_request of this RecordQueryResponse.


        :param search_request: The search_request of this RecordQueryResponse.  # noqa: E501
        :type: SearchRequest
        """
        if self.local_vars_configuration.client_side_validation and search_request is None:  # noqa: E501
            raise ValueError("Invalid value for `search_request`, must not be `None`")  # noqa: E501

        self._search_request = search_request

    @property
    def total_records(self):
        """Gets the total_records of this RecordQueryResponse.  # noqa: E501

        number of records in the record type  # noqa: E501

        :return: The total_records of this RecordQueryResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_records

    @total_records.setter
    def total_records(self, total_records):
        """Sets the total_records of this RecordQueryResponse.

        number of records in the record type  # noqa: E501

        :param total_records: The total_records of this RecordQueryResponse.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_records is None:  # noqa: E501
            raise ValueError("Invalid value for `total_records`, must not be `None`")  # noqa: E501

        self._total_records = total_records

    @property
    def records(self):
        """Gets the records of this RecordQueryResponse.  # noqa: E501

        list of records found  # noqa: E501

        :return: The records of this RecordQueryResponse.  # noqa: E501
        :rtype: list[RecordResponse]
        """
        return self._records

    @records.setter
    def records(self, records):
        """Sets the records of this RecordQueryResponse.

        list of records found  # noqa: E501

        :param records: The records of this RecordQueryResponse.  # noqa: E501
        :type: list[RecordResponse]
        """
        if self.local_vars_configuration.client_side_validation and records is None:  # noqa: E501
            raise ValueError("Invalid value for `records`, must not be `None`")  # noqa: E501

        self._records = records

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecordQueryResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RecordQueryResponse):
            return True

        return self.to_dict() != other.to_dict()
